VQA Guide
=========

Variational quantum algorithms (VQAs) are a promising class of near-term algorithms which can be (easily) implemented using Orquestra Core.

.. toctree::
    :maxdepth: 2
    
    introduction.rst
    structure.rst
    ansatzes.rst
    estimators.rst